Data documentation compiled by Great Expectations

### Validation Overview

#### Info

Full Data Asset Identifier |
Expectation Suite Name | default
Great Expectations Version | __fixture__
Run ID | __run_id_fixture__
Validation Succeeded | False

#### Statistics

Evaluated Expectations | 51
Successful Expectations | 43
Unsuccessful Expectations | 8
Success Percent | 84.31%

### Unnamed: 0

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int. | int64
| may have any number of unique values. | 1313
| may have any percentage of unique values. | 1.0
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value | Count
--- | ---
1 | 1
2 | 1
3 | 1
4 | 1
5 | 1
6 | 1
7 | 1
8 | 1
9 | 1
10 | 1
11 | 1
12 | 1
13 | 1
14 | 1
15 | 1
16 | 1
17 | 1
18 | 1
19 | 1
20 | 1
| 100.0000% unexpected
| values must be unique. | 0.0000% unexpected

### Name

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: CHAR StringType TEXT VARCHAR str string. | 0.0000% unexpected
| may have any number of unique values. | 1310
| may have any percentage of unique values. | 0.9977151561309977
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value | Count
--- | ---
Carlsson, Mr Frans Olof | 2
Connolly, Miss Kate | 2
Kelly, Mr James | 2
Allen, Miss Elisabeth Walton | 1
Allison, Master Hudson Trevor | 1
Allison, Miss Helen Loraine | 1
Allison, Mr Hudson Joshua Creighton | 1
Allison, Mrs Hudson JC (Bessie Waldo Daniels) | 1
Anderson, Mr Harry | 1
Andrews, Miss Kornelia Theodosia | 1
Andrews, Mr Thomas, jr | 1
Appleton, Mrs Edward Dale (Charlotte Lamson) | 1
Artagaveytia, Mr Ramon | 1
Astor, Colonel John Jacob | 1
Astor, Mrs John Jacob (Madeleine Talmadge Force) | 1
Aubert, Mrs Leontine Pauline | 1
Barkworth, Mr Algernon H | 1
Baumann, Mr John D | 1
Baxter, Mr Quigg Edmond | 1
Baxter, Mrs James (Helene DeLaudeniere Chaput) | 1
| 100.0000% unexpected
| values must not match this regular expression: ^\s+|\s+$. 3 unexpected values found. 0.23% of 1313 total rows.
Unexpected Value | Count
--- | ---
Barber, Ms | 1
Daly, Mr Peter Denis | 1
Geiger, Miss Emily | 1
| 0.2285% unexpected

### PClass

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: CHAR StringType TEXT VARCHAR str string. | 0.0000% unexpected
| may have any number of unique values. | 4
| may have any percentage of unique values. | 0.0030464584920030465
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value | Count
--- | ---
3rd | 711
1st | 322
2nd | 279
* | 1
| 100.0000% unexpected
| values must not match this regular expression: ^\s+|\s+$. | 0.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | ['*', '1st', '2nd', '3rd']

### Age

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: DOUBLE_PRECISION DoubleType FLOAT FLOAT4 FLOAT8 FloatType NUMERIC float. | float64
| may have any number of unique values. | 75
| may have any percentage of unique values. | 0.0992063492063492
| values must not be null, at least 50.0 % of the time. | 57.5781% not null
| values must belong to this set: [ ]. 756 unexpected values found. 57.58% of 1313 total rows.
Unexpected Value | Count
--- | ---
22.0 | 35
21.0 | 31
30.0 | 31
18.0 | 30
36.0 | 29
24.0 | 27
26.0 | 27
27.0 | 24
28.0 | 24
19.0 | 23
20.0 | 23
23.0 | 23
25.0 | 23
32.0 | 22
45.0 | 20
29.0 | 15
31.0 | 14
33.0 | 14
35.0 | 14
39.0 | 14
| 57.5781% unexpected
| minimum value may have any numerical value. | 0.17
| maximum value may have any numerical value. | 71.0
| mean may have any numerical value. | 30.397989417989418
| median may have any numerical value. | 28.0
| expect_column_quantile_values_to_be_between(**{'column': 'Age', 'quantile_ranges': {'quantiles': [0.05, 0.25, 0.5, 0.75, 0.95], 'value_ranges': [[None, None], [None, None], [None, None], [None, None], [None, None]]}, 'result_format': 'SUMMARY'}) | {'quantiles': [0.05, 0.25, 0.5, 0.75, 0.95], 'values': [6.0, 21.0, 28.0, 39.0, 57.0]}
| Kullback-Leibler (KL) divergence with respect to a given distribution must be lower than a provided threshold but no distribution was specified. | --

### Sex

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: CHAR StringType TEXT VARCHAR str string. | 0.0000% unexpected
| may have any number of unique values. | 2
| may have any percentage of unique values. | 0.0015232292460015233
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value | Count
--- | ---
male | 851
female | 462
| 100.0000% unexpected
| values must not match this regular expression: ^\s+|\s+$. | 0.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | ['female', 'male']

### Survived

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int. | int64
| may have any number of unique values. | 2
| may have any percentage of unique values. | 0.0015232292460015233
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value | Count
--- | ---
null | 863
1 | 450
| 100.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | [0, 1]

### SexCode

Status | Expectation | Observed Value
--- | --- | ---
| value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int. | int64
| may have any number of unique values. | 2
| may have any percentage of unique values. | 0.0015232292460015233
| values must not be null, at least 50.0 % of the time. | 100.0000% not null
| values must belong to this set: [ ]. 1313 unexpected values found. 100.00% of 1313 total rows.
Unexpected Value | Count
--- | ---
null | 851
1 | 462
| 100.0000% unexpected
| distinct values must belong to a set, but that set is not specified. | [0, 1]

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.